@@ -35,17 +35,12 @@ class Domoticz(IPlugin):
 		bodies = ""
 		entity = jsonInput['outcome']['intent']
 		log.msg("entity :  %s" % (entity))		
-		if jsonInput['outcome']['entities']['location']['body'] :
+		if ( entity ="dz_loc_bureau_deux" or entity ="dz_loc_bureau_un" or entity ="dz_loc_carrillon" or entity ="dz_loc_salon" ) :
+			on_off = jsonInput['outcome']['entities']['on_off']['value']
+			location = "VIDE"
+		if entity ="dz_loc_frisquet"  :
+			on_off = jsonInput['outcome']['entities']['on_off']['value']
 			location = jsonInput['outcome']['entities']['location']['body']
-
-#		else:
-#			bodies = "pas de lieu"
-#			location= "VIDE"
-#		if jsonInput['outcome']['entities']['on_off']['value'] :
-#			on_off = jsonInput['outcome']['entities']['on_off']['value']
-#		else:
-#			bodies = "pas de on/off"
-#			on_off = "VIDE"
 		idex= location + "_" + on_off
 		log.msg("index :  %s" % (idex))		
 		for rs in self.configuration_plugin['param_dz']:
